@@ -55,12 +55,21 @@ switch=$1
 
 case "$switch" in
    "start"|"restart")
+     # run drblpush again so that the network interface can be updated. Maybe there is new ethx.
+     # load $client_no_per_NIC
+     . /opt/drbl/setup/files/ocs/live-hook/ocs-live.conf
+     yes "" | drblpush -i -r 1 -z 1 -p $client_no_per_NIC
      # turn on tcpwrapper
      echo "Setting /etc/hosts.allow..."
      mv -f /etc/hosts.allow /etc/hosts.allow.orig
      client_IP_list="$($DRBL_SCRIPT_PATH/bin/get-client-ip-list)"
      client_IP_list="$(echo $client_IP_list)"   # convert to 1 line
-     echo "ALL: $client_IP_list" > /etc/hosts.allow
+     client_IP_list_ar=( $client_IP_list )  # put it in an array
+     # We can not list too long in hosts.allow, so put 20 elements in a line.
+     nloop="$(echo "scale=0; ${#client_IP_list_ar[@]}/20 + 1" | bc -l )"
+     for i in {1..$nloop}; do
+       echo "ALL: ${client_IP_list_ar[@]:0:19}" > /etc/hosts.allow
+     done
 
      # add and start all services
      echo "Adding DRBL-related services..."
